@@ -34,6 +34,7 @@ test_order= {
         'test_ROS_urdf'
         ],
     'dynamixel':[
+        'test_DYNAMIXEL_hardware',
         'test_DYNAMIXEL_measure_efforts',
         'test_DYNAMIXEL_measure_range_of_motion',
         'test_DYNAMIXEL_check_zero_position'
@@ -44,7 +45,8 @@ test_order= {
      'stepper':[
          'test_STEPPER_calibration_data_match',
          'test_STEPPER_runstop',
-         'test_STEPPER_sync'
+         'test_STEPPER_sync',
+         'test_STEPPER_power'
          ],
     'arm':['test_ARM_effort_through_range_of_motion'],
     'lift': ['test_LIFT_effort_through_range_of_motion'],
